@@ -22,8 +22,13 @@
 # Boston, MA 02110-1301 USA,
 
 import unittest
-from xml.dom import minidom
 import xml.etree.ElementTree as ET
+from xml.dom import minidom
+from src.dame_formats import DameFormats
+# fix for MacOS using nose
+import collections
+collections.Callable = collections.abc.Callable
+
 
 class TestDameXml(unittest.TestCase):
 
@@ -47,6 +52,7 @@ class TestDameXml(unittest.TestCase):
                 l1.append(elem.text)
         self.assertEqual(l1[0:2], ["Richard Stallman's Political Notes",
                                    'Economic growth and fossil fuels'])
+
     def test_damexml_root(self):
         tree = ET.parse('files/rss.xml')
         root = tree.getroot()
@@ -76,7 +82,7 @@ class TestDameXml(unittest.TestCase):
             l0.append(event)
             l1.append(elem)
         self.assertEqual(len(l0), 2)
-        self.assertEqual(len(l1), 2)        
+        self.assertEqual(len(l1), 2)
         parser2 = ET.XMLPullParser(['start', 'end'])
         parser2.feed('<a>')
         parser2.feed('</a>')
@@ -87,7 +93,7 @@ class TestDameXml(unittest.TestCase):
             l3.append(elem2)
         self.assertEqual(len(l2), 2)
         self.assertEqual(len(l3), 2)
-        
+
     def test_damexml_xpath(self):
         tree = ET.parse("files/html.html")
         p = tree.find("body/p")
@@ -101,8 +107,8 @@ class TestDameXml(unittest.TestCase):
         self.assertEqual(len(links), 0)
         texts = list(p.itertext())
         self.assertEqual(len(texts), 1)
-        self.assertEqual(texts[0], "Moved to example.org or example.com.")        
-        
+        self.assertEqual(texts[0], "Moved to example.org or example.com.")
+
     def test_damexml_xpath3(self):
         tree = ET.parse('files/countries.xml')
         root = tree.getroot()
@@ -112,12 +118,53 @@ class TestDameXml(unittest.TestCase):
         years = root.findall('./country/year')
         self.assertEqual(len(years), 2)
         self.assertEqual(years[0].text, '2008')
-        self.assertEqual(years[1].text, '2011')        
+        self.assertEqual(years[1].text, '2011')
         ranking = root.findall('./country/rank')
         self.assertEqual(len(ranking), 2)
         self.assertEqual(ranking[0].attrib, {'updated': 'yes'})
-        neighborhood = root.findall('./country/neighbor')        
-        self.assertEqual(neighborhood[0].attrib, {'name': 'Austria', 'direction': 'E'})
+        neighborhood = root.findall('./country/neighbor')
+        self.assertEqual(neighborhood[0].attrib,
+                         {'name': 'Austria', 'direction': 'E'})
+
+    def test_damexml_xpath_detect_david_gender(self):
+        tree = ET.parse("files/david.html")
+        root = tree.getroot()
+        self.assertEqual(root.tag, 'html')
+        body = root.findall('./body')
+        str1 = './body/div[@class="mw-body"]/div[@class="vector-body"]'
+        divs1 = root.findall(str1)
+        self.assertEqual(len(divs1), 1)
+        self.assertEqual(len(divs1[0]), 8)
+        str2 = './body/div[@class="mw-body"]/div[@class="vector-body"]'
+        str2 = str2 + '/div[@id="mw-content-text"]'
+        str2 = str2 + '/div[@class="mw-parser-output"]'
+        divs2 = root.findall(str2)
+        self.assertEqual(len(divs2), 1)
+        str3 = './body/div[@class="mw-body"]/div[@class="vector-body"]'
+        str3 = str3 + '/div[@id="mw-content-text"]'
+        str3 = str3 + '/div[@class="mw-parser-output"]/table/tbody'
+        divs3 = root.findall(str3)
+        self.assertEqual(len(divs3), 2)
+        str4 = './body/div[@class="mw-body"]/div[@class="vector-body"]'
+        str4 = str4 + '/div[@id="mw-content-text"]'
+        str4 = str4 + '/div[@class="mw-parser-output"]'
+        str4 = str4 + '/table/tbody/tr/td'
+        divs4 = root.findall(str4)
+        male = False
+        self.assertTrue(len(divs4) > 2)
+        print(divs4)
+        l0 = []
+        for i in divs4:
+            l0.append(i.text)
+        if ("Male" in l0):
+            male = True
+        self.assertTrue(male)
+
+    def test_is_xml(self):
+        df = DameFormats()
+        file2 = "files/items.xml"
+        self.assertFalse(df.is_xml(file2))
         
+
 if __name__ == '__main__':
     unittest.main()
